<?php
/**
 * $Horde: whups/runquery.php,v 1.34 2006/01/01 21:12:13 jan Exp $
 *
 * Copyright 2001-2006 Robert E. Coyle <robertecoyle@hotmail.com>
 * Copyright 2001-2006 Chuck Hagenbuch <chuck@horde.org>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 */

@define('WHUPS_BASE', dirname(__FILE__));
require_once WHUPS_BASE . '/lib/base.php';
require_once WHUPS_BASE . '/lib/Query.php';
require_once 'Horde/Variables.php';
require WHUPS_TEMPLATES . '/queryrenderer.inc';
require WHUPS_TEMPLATES . '/searchresults.inc';

$vars = &Variables::getDefaultVariables();
$qManager = &Whups_QueryManager::singleton();

// Load the current query. If we have a 'query' parameter, that
// overrides and we load in that from the query store. Otherwise we
// use the query that is currently in our session.
if ($vars->exists('query')) {
    $whups_query = &$qManager->getShare($vars->get('query'));
} elseif (isset($_SESSION['whups_query'])) {
    $whups_query = unserialize($_SESSION['whups_query']);
}

// If we still don't have a query, or if we don't have read
// permissions on the requested query, go to the initial Whups page.
if (!isset($whups_query) || !$whups_query->hasPermission(Auth::getAuth(), PERMS_READ)) {
    if (isset($whups_query)) {
        $notification->push(_("Permission denied."), 'horde.error');
    }
    header('Location: ' . Horde::applicationUrl($prefs->getValue('whups_default_view') . '.php', true));
    exit;
}

// Query actions.
$tabs = &$whups_query->getTabs($vars);

$renderer = &new Horde_Form_Renderer();

// Update sorting preferences.
if (Util::getFormData('sortby') !== null) {
    $prefs->setValue('sortby', Util::getFormData('sortby'));
}
if (Util::getFormData('sortdir') !== null) {
    $prefs->setValue('sortdir', Util::getFormData('sortdir'));
}

$form = &$whups_query->getParameterForm($vars);
$isvalid = false;
$tickets = null;

if ($form === null) {
    $isvalid = true;
} elseif ($vars->get('formname') == 'queryparameters') {
    $isvalid = $form->validate($vars);
}

if ($isvalid) {
    $tickets = $whups->executeQuery($whups_query, $vars);
    $_SESSION['whups_last_search'] = Horde::applicationUrl('runquery.php');
}

$title = _("Execute Query");
require WHUPS_TEMPLATES . '/common-header.inc';
require WHUPS_TEMPLATES . '/menu.inc';

echo $tabs->render($vars->get('action') ? $vars->get('action') : 'run');

if (isset($tickets)) {
    Whups::sortTickets($tickets);
    $results = &new SearchResults(_("Query Results"));
    $results->results($tickets, Whups::getSearchResultColumns(WHUPS_RESULTS_QUERY));
} else {
    $form->open($renderer, $vars, 'runquery.php');
    $renderer->beginActive($form->getTitle());
    $renderer->renderFormActive($form, $vars);
    $renderer->submit(_("Execute Query"));
    $renderer->end();
    $form->close($renderer);
}

require $registry->get('templates', 'horde') . '/common-footer.inc';

$_SESSION['whups_query'] = serialize($whups_query);
