#!/usr/local/bin/php
<?php
/**
 * $Horde: whups/scripts/upgrades/2003-06-19_allow_multiple_owners.php,v 1.1 2004/09/02 19:43:23 chuck Exp $
 *
 * This is a script to migrate old tickets so they can support
 * multiple owners.
 */

@define('AUTH_HANDLER', true);
@define('HORDE_BASE', dirname(__FILE__) . '/../..');
@define('WHUPS_BASE', HORDE_BASE . '/whups');

// Do CLI checks and environment setup first.
require_once HORDE_BASE . '/lib/core.php';
require_once 'Horde/CLI.php';

// Make sure no one runs this from the web.
if (!Horde_CLI::runningFromCLI()) {
    exit("Must be run from the command line\n");
}

// Load the CLI environment - make sure there's no time limit, init
// some variables, etc.
Horde_CLI::init();

require_once WHUPS_BASE . '/lib/base.php';
require_once WHUPS_BASE . '/lib/Driver.php';

$db = &$whups->_db;
$output = '';

// Create new table.
$sql = "CREATE TABLE whups_ticket_owners (
    ticket_id           INT NOT NULL,
    ticket_owner        VARCHAR(255) NOT NULL
);";

$result = $db->query($sql);
if (is_a($result, 'PEAR_Error')) {
    $output .= "Could not create table whups_ticket_owners.\n";
    $output .= $result->toString() . "\n\n";
}

$sql = 'CREATE INDEX ticket_id_idx ON TABLE whups_ticket_owners (ticket_id)';
$result = $db->query($sql);
if (is_a($result, 'PEAR_Error')) {
    $output .= "Could not create index for ticket_id on table whups_ticket_owners.\n";
    $output .= $result->toString() . "\n\n";
}

$sql = 'CREATE INDEX ticket_owner_idx ON TABLE whups_ticket_owners (ticket_owner)';
$result = $db->query($sql);
if (is_a($result, 'PEAR_Error')) {
    $output .= "Could not create index for ticket_owner on table whups_ticket_owners.\n";
    $output .= $result->toString() . "\n\n";
}

// Add new field to whups_logs table
$sql = 'ALTER TABLE whups_logs ADD COLUMN user_id VARCHAR(255)';
$result = $db->query($sql);
if (is_a($result, 'PEAR_Error')) {
    $output .= "Could not add new column to table whups_logs.\n";
    $output .= $result->toString() . "\n\n";
}

// Logs.
$sql = "UPDATE whups_logs SET user_id = user_id_owner ";
$result = $db->query($sql);
if (is_a($result, 'PEAR_Error')) {
    $output .= "Could not update contents of field user_id in table whups_logs.\n";
    $output .= $result->toString() . "\n\n";
}

$sql = "ALTER TABLE whups_logs DROP COLUMN user_id_owner";
$result = $db->query($sql);
if (is_a($result, 'PEAR_Error')) {
    $output .= "Could not remove old user_id_owner column in table whups_logs.\n";
    $output .= $result->toString() . "\n\n";
}

// Ticket owners.
$sql = "SELECT ticket_id, user_id_owner FROM whups_tickets ";
$tickets = $db->getAll($sql);
for ($i=0;$i<count($tickets);$i++) {
    $ticket_id = $tickets[$i][0];
    $ticket_owner = $tickets[$i][1];
    if (!empty($ticket_owner)) {
        $sql = "INSERT INTO whups_ticket_owners (ticket_id, ticket_owner)
                VALUES ($ticket_id, 'user:$ticket_owner') ";
        $result = $db->query($sql);
        if (is_a($result, 'PEAR_Error')) {
            $output .= "Could not add owner into table whups_ticket_owners.\n";
            $output .= $result->toString() . "\n\n";
        }
    }
}

// Now remove old columns.
$sql = "ALTER TABLE whups_tickets DROP COLUMN user_id_owner";
$result = $db->query($sql);
if (is_a($result, 'PEAR_Error')) {
    $output .= "Could not remove old user_id_owner column in table whups_tickets.\n";
    $output .= $result->toString() . "\n\n";
}

if (empty($output)) {
    echo "Migrated successfully.\n";
} else {
    echo $output."\n";
}
