#!/usr/local/bin/php
<?php
/**
 * $Horde: whups/scripts/upgrades/2004-12-18_log_value_num.php,v 1.2 2004/12/23 10:34:02 jan Exp $
 *
 * This is a script to update the whups_logs table to store numeric
 * log values as well as strings, effective 2004-12-18.
 */

@define('AUTH_HANDLER', true);
@define('HORDE_BASE', dirname(__FILE__) . '/../../..');
@define('WHUPS_BASE', HORDE_BASE . '/whups');

// Do CLI checks and environment setup first.
require_once HORDE_BASE . '/lib/core.php';
require_once 'Horde/CLI.php';

// Make sure no one runs this from the web.
if (!Horde_CLI::runningFromCLI()) {
    exit("Must be run from the command line\n");
}

// Load the CLI environment - make sure there's no time limit, init
// some variables, etc.
Horde_CLI::init();
$cli = &Horde_CLI::singleton();

require_once WHUPS_BASE . '/lib/base.php';
require_once WHUPS_BASE . '/lib/Driver.php';
$db = &$whups->_db;

// Fetch the current structure of the logs table.
$info = $db->tableInfo('whups_logs');

// These are the things we might need to do. We'll look at the table
// structure next to figure out which of them we still need to do.
$add_logvaluenum = true;
$migrate_logvalues = true;

// See what the structure says we should do.
foreach ($info as $field) {
    if ($field['name'] == 'log_value_num') {
        $add_logvaluenum = false;
    }
}

// Tell the user what we're going to do.
if ($add_logvaluenum || $migrate_logvalues) {
    $cli->writeln('Will perform these actions:');
    if ($add_logvaluenum) {
        $cli->writeln('- Add LOG_VALUE_NUM field.');
    }
    if ($migrate_logvalues) {
        $cli->writeln('- Populate LOG_VALUE contents into LOG_VALUE_NUM.');
    }
} else {
    $cli->writeln($cli->blue('Nothing to do!'));
    exit;
}

// Time to start converting.
$cli->writeln();

// Need to do this first so nothing else fails.
if ($add_logvaluenum) {
    fquery("ALTER TABLE whups_logs ADD COLUMN log_value_num INT");
}

// Now fill LOG_VALUE_NUM with numeric representation of LOG_VALUE
if ($migrate_logvalues) {

    $entries = $db->getAll('SELECT log_id, log_value FROM whups_logs', DB_FETCHMODE_ASSOC);
    if (is_a($entries, 'PEAR_Error')) {
        $cli->fatal($entries->getMessage());
    }

    foreach ($entries as $entry) {
        $query = 'UPDATE whups_logs SET log_value_num = ' .
            (int)$entry['log_value'] .
            ' WHERE log_id = ' . $entry['log_id'];
        $result = fquery($query);
    }
}

$cli->writeln($cli->green('DONE!'));
exit;


function fquery($sql)
{
    global $db, $cli;

    $result = $db->query($sql);
    if (is_a($result, 'PEAR_Error')) {
        $cli->fatal($result->getMessage() . ": " . $result->getUserInfo());
    }

    return $result;
}
