<?php
/**
 * $Horde: whups/search.php,v 1.93 2006/01/01 21:12:13 jan Exp $
 *
 * Copyright 2001-2006 Robert E. Coyle <robertecoyle@hotmail.com>
 * Copyright 2001-2006 Chuck Hagenbuch <chuck@horde.or>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 */

@define('WHUPS_BASE', dirname(__FILE__));
require_once WHUPS_BASE . '/lib/base.php';
require_once WHUPS_BASE . '/lib/Query.php';
require_once 'Horde/Variables.php';
require_once WHUPS_TEMPLATES . '/searchresults.inc';
require_once WHUPS_TEMPLATES . '/savedsearches.inc';
require_once WHUPS_TEMPLATES . '/savedqueries.inc';

/**
 * SearchForm Class.
 *
 * @author  Robert E. Coyle <robertecoyle@hotmail.com>
 * @package Whups
 */
class SearchForm extends Horde_Form {

    var $_useFormToken = false;

    function SearchForm(&$vars)
    {
        global $whups, $conf;

        parent::Horde_Form($vars);

        $queues = Whups::permissionsFilter($whups->getQueues(), 'queue', PERMS_READ);
        if (count($queues)) {
            $modtype = 'enum';
            $type_params = array(array('0' => _("Any")) + $queues);
        } else {
            $modtype = 'invalid';
            $type_params = array(_("There are no queues which you can search."));
        }

        $count = &$this->addHidden('', 'count', 'int', false, true);
        $count->setDefault(10);

        $this->addVariable(_("Queue"), 'queue', $modtype, false, false, null, $type_params);
        $this->addVariable(_("Ticket ID"), 'id', 'intlist', false);
        $this->addVariable(_("Summary like"), 'summary', 'text', false);

        $cats = &$this->addVariable(_("Tickets which are"), 'category', 'multienum', false, false, _("If you don't select any categories, no filtering will be done on ticket category."), array($whups->getCategories(), 4));
        $cats->setDefault(array('unconfirmed', 'new', 'assigned'));

        $this->addVariable(_("Types"), 'type', 'multienum', false, false, _("If you don't select any types, no filtering will be done on ticket type."), array($whups->getAllTypes(), 4));
    }

}

$renderer = &new Horde_Form_Renderer();
$beendone = 0;
$vars = &Variables::getDefaultVariables();

$title = _("Search Tickets");
require WHUPS_TEMPLATES . '/common-header.inc';
require WHUPS_TEMPLATES . '/menu.inc';

// Update sorting preferences.
if (Util::getFormData('sortby') !== null) {
    $prefs->setValue('sortby', Util::getFormData('sortby'));
}
if (Util::getFormData('sortdir') !== null) {
    $prefs->setValue('sortdir', Util::getFormData('sortdir'));
}

$form = &Horde_Form::singleton('SearchForm', $vars);
if ($vars->exists('queue') && $form->validate($vars, true)) {
    $form->getInfo($vars, $info);

    $cat = $vars->get('category');
    $type = $vars->get('type');
    $summary = $vars->get('summary');

    $qUrl = Util::addParameter('', array('queue' => $vars->get('queue'),
                                         'id' => $vars->get('id')));
    if ($summary) {
        $qUrl = Util::addParameter($qUrl, 'summary', $summary);
    }
    if (is_array($cat)) {
        foreach ($cat as $c) {
            $qUrl = Util::addParameter($qUrl, 'category[]', $c);
        }
    }
    if (is_array($type)) {
        foreach ($type as $t) {
            $qUrl = Util::addParameter($qUrl, 'type[]', $t);
        }
    }
    $qUrl = substr($qUrl, 1);
    $_SESSION['whups_last_search'] = Horde::applicationUrl("search.php?$qUrl");

    if (Auth::getAuth()) {
        $idName = $vars->get('id') ? $vars->get('id') : _("Any");
        $queueInfo = $whups->getQueue($info['queue']);
        $queueName = !empty($queueInfo['name']) ? $queueInfo['name'] : _("Any");
        if ($cat) {
            $categories = $whups->getCategories();
            if (is_array($cat)) {
                $catName = '';
                foreach ($cat as $c) {
                    if (!empty($catName)) {
                        $catName .= ', ';
                    }
                    $catName .= $categories[$c];
                }
            } else {
                $catName = $categories[$cat];
            }
        } else {
            $catName = _("Any");
        }
        if ($type) {
            $types = $whups->getAllTypes();
            if (is_array($type)) {
                $typeName = '';
                foreach ($type as $t) {
                    if (!empty($typeName)) {
                        $typeName .= ', ';
                    }
                    $typeName .= $types[$t];
                }
            } else {
                $typeName = $types[$type];
            }
        } else {
            $typeName = _("Any");
        }
        $summaryName = $summary ? $summary : _("Any");
        $whups->saveSearch(sprintf(_("Queue: %s, Ticket: %s, Category: %s, Type: %s, Summary: %s"), $queueName, $idName, $catName, $typeName, $summary), $qUrl);
    }

    // Munge the search criteria into acceptability.
    if (empty($info['queue'])) {
        $info['queue'] = array_keys(Whups::permissionsFilter($whups->getQueues(), 'queue', PERMS_READ, Auth::getAuth(), Auth::getAuth()));
    }
    if (empty($info['id'])) {
        unset($info['id']);
    }
    if (empty($info['category'])) {
        unset($info['category']);
    }
    if (empty($info['type'])) {
        unset($info['type']);
    }

    $tickets = $whups->getTicketsByProperties($info);
    if (is_a($tickets, 'PEAR_Error')) {
        $notification->push(sprintf(_("There was an error performing your search: %s"), $tickets->getMessage()), 'horde.error');
    } else {
        Whups::sortTickets($tickets);

        $values = Whups::getSearchResultColumns(WHUPS_RESULTS_SEARCH);

        $results = &new SearchResults(_("Search Results"));
        $results->results($tickets, $values);
        $beendone = 1;

        if (is_object($form)) {
            $form->setTitle(_("Refine Search"));
            $form->renderActive($renderer, $vars, 'search.php', 'post');
            echo '<br />';

            $beendone = 1;
        }
    }
}

if (!$beendone) {
    // Front search page.
    $form->setTitle(_("Search Tickets"));
    $form->renderActive($renderer, $vars, 'search.php', 'post');
    echo '<br class="spacer" />';
}

if (Auth::getAuth()) {
    $mysearches = &new SavedSearches();
    $mysearches->render(_("My QuickSearches"), $renderer, $whups->getUserSearches(Auth::getAuth()));

    $qManager = &Whups_QueryManager::singleton();
    $myqueries = &new SavedQueries();
    $myqueries->render(_("My Queries"), $renderer, $qManager->listShares(Auth::getAuth()));
}

require $registry->get('templates', 'horde') . '/common-footer.inc';
